pub struct BoardConfig {
pub devices: Option<Vec<Device>>,
pub aggregates: Option<Vec<AggregateEntry>>,
/* private fields */
}Fields
devices: Option<Vec<Device>>aggregates: Option<Vec<AggregateEntry>>Trait Implementations
Sourceimpl Clone for BoardConfig
impl Clone for BoardConfig
Sourcefn clone(&self) -> BoardConfig
fn clone(&self) -> BoardConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoardConfig
impl Debug for BoardConfig
Sourceimpl<D> Decode<BoardConfig, D> for BoardConfigwhere
D: ResourceDialect,
impl<D> Decode<BoardConfig, D> for BoardConfigwhere
D: ResourceDialect,
Sourcefn new_empty() -> BoardConfig
fn new_empty() -> BoardConfig
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for BoardConfig
impl Default for BoardConfig
Sourcefn default() -> BoardConfig
fn default() -> BoardConfig
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<BoardConfig, D> for &BoardConfigwhere
D: ResourceDialect,
impl<D> Encode<BoardConfig, D> for &BoardConfigwhere
D: ResourceDialect,
Sourceimpl PartialEq for BoardConfig
impl PartialEq for BoardConfig
Sourcefn eq(&self, other: &BoardConfig) -> bool
fn eq(&self, other: &BoardConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for BoardConfig
impl StructuralPartialEq for BoardConfig
Sourceimpl TypeMarker for BoardConfig
impl TypeMarker for BoardConfig
Sourcetype Owned = BoardConfig
type Owned = BoardConfig
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for BoardConfig
impl ValueTypeMarker for BoardConfig
Sourcetype Borrowed<'a> = &'a BoardConfig
type Borrowed<'a> = &'a BoardConfig
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<BoardConfig as TypeMarker>::Owned,
) -> <BoardConfig as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<BoardConfig as TypeMarker>::Owned, ) -> <BoardConfig as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for BoardConfig
impl RefUnwindSafe for BoardConfig
impl Send for BoardConfig
impl Sync for BoardConfig
impl Unpin for BoardConfig
impl UnsafeUnpin for BoardConfig
impl UnwindSafe for BoardConfig